@@ -58,6 +58,10 @@ public:
 	virtual _i64 getTransferedBytes(void);
 
 	virtual void resetTransferedBytes(void);
+	
+	virtual void setUsageString(const std::string& str);
+
+	virtual bool setCompressionSettings(const SCompressionSettings& params);
 
 private:
 
