@@ -34,6 +34,11 @@ namespace
 #endif //HAVE_MNTENT_H
 	}
 
+	std::string getRootVol()
+    {
+        return getMountDevice("/");
+    }
+
     std::string getSysVolumeCached(std::string& mpath)
     {
         mpath = getMountDevice("/boot");
@@ -42,13 +47,9 @@ namespace
 
     std::string getEspVolumeCached(std::string& mpath)
     {
-        return "";
-    }
-
-    std::string getRootVol()
-    {
-        return getMountDevice("/");
-    }
+        mpath = getMountDevice("/boot/efi");
+        return mpath;
+    }    
 
 	bool isDevice(const std::string& path)
 	{
